var electron = require('electron');
var app = electron.app;
var BrowserWindow = electron.BrowserWindow;
var path = require('path');
var url = require('url');

// Keep a global reference of the window object, if you don't, the window will
// be closed automatically when the JavaScript object is garbage collected.
var win;

function createWindow () {
  // Create the browser window.
  win = new BrowserWindow({width: 800, height: 600});

  var tray = require('./tray');
  tray.init(win);

  var menu = require('./menu');
  menu.init(win);

  // and load the index.html of the app.
  win.loadURL(url.format({
    pathname: path.join(__dirname, 'index.html'),
    protocol: 'file:',
    slashes: true
  }));

  // Open the DevTools.
  win.webContents.openDevTools();

  // Emitted when the window is closed.
  win.on('close', function (e) {
    if (process.platform !== 'darwin') {
      if (!tray.hasTray()) {
        app.quit();
        return;
      }
    }
    // We are either on Mac with a dock, or a system where we want to minimize to the tray, so
    // don't actually close, just hide the window.
    if (!app.isQuitting) {
      e.preventDefault();
      win.hide();
    }
  });
}

// This method will be called when Electron has finished
// initialization and is ready to create browser windows.
// Some APIs can only be used after this event occurs.
app.on('ready', createWindow);

// Mark the application as quitting so the logic we have to minimize to the tray on window
// close doesn't prevent the proper exitting of the application.
app.on('before-quit', function () {
  app.isQuitting = true;
});

app.on('activate', function () {
  // On macOS it's common to re-create a window in the app when the
  // dock icon is clicked and there are no other windows open.
  if (win) {
    win.show();
  }
});

// In this file you can include the rest of your app's specific main process
// code. You can also put them in separate files and require them here.
